@@ -1,6 +1,6 @@
 from .base import Identifiable, UserRole
 from .core import Flask, configure_logging, configure_whooshee, configure_sqlalchemy
-from .restx import counter_parser, password_parser
+from .restx import RequestParser, counter_parser, password_parser
 from .restx import ResourceController, Undefined
 from .restx import ResponseDoc, DateTimeField, Model, PydanticModel
 from .siox import ClientEvent, ServerEvent, DuplexEvent, EventException
